Merge "[qca-nss-ecm] Inner/Outer framework support for tunipip6."
diff --git a/Makefile b/Makefile
index f778300..cd25069 100755
--- a/Makefile
+++ b/Makefile
@@ -52,7 +52,7 @@
 # Define ECM_FRONT_END_NSS_ENABLE=y in order to select
 # nss as ECM's front end.
 # #############################################################################
-ifeq ($(SoC),$(filter $(SoC),ipq806x ipq807x ipq807x_64))
+ifeq ($(SoC),$(filter $(SoC),ipq806x ipq807x ipq807x_64 ipq60xx ipq60xx_64))
 ECM_FRONT_END_NSS_ENABLE=y
 ecm-$(ECM_FRONT_END_NSS_ENABLE) += frontends/nss/ecm_nss_ipv4.o
 ecm-$(ECM_FRONT_END_NSS_ENABLE) += frontends/nss/ecm_nss_ported_ipv4.o
diff --git a/frontends/include/ecm_front_end_types.h b/frontends/include/ecm_front_end_types.h
index a7ad880..c13ff9f 100644
--- a/frontends/include/ecm_front_end_types.h
+++ b/frontends/include/ecm_front_end_types.h
@@ -214,7 +214,7 @@
  * hardware support it, then SFE front end.
  *
  * We check device tree to see if NSS is supported by hardware.
  * Currenly all ipq8064, ipq8062 and ipq807x platforms support NSS.
  * Since SFE is a pure software acceleration engine, so all platforms
  * support it.
  */
@@ -223,7 +223,8 @@
 #ifdef CONFIG_OF
 	bool nss_supported = of_machine_is_compatible("qcom,ipq8064") ||
 				of_machine_is_compatible("qcom,ipq8062") ||
-				of_machine_is_compatible("qcom,ipq807x");
+				of_machine_is_compatible("qcom,ipq807x") ||
+				of_machine_is_compatible("qcom,ipq60xx");
 #else
 	bool nss_supported = true;
 #endif
@@ -214,7 +214,7 @@
  *
  * We check device tree to see if NSS is supported by hardware.
- * Currenly all ipq8064, ipq8062 and ipq807x platforms support NSS.
+ * Currenly all ipq8064, ipq8062 and ipq807x  ipq60xx platforms support NSS.
  * Since SFE is a pure software acceleration engine, so all platforms
  * support it.